probnum.filtsmooth
==================

Bayesian Filtering and Smoothing.

This package provides different kinds of Bayesian filters and smoothers which
estimate the distribution over observed and hidden variables in a sequential model.
The two operations differ by what information they use. Filtering considers all
observations up to a given point, while smoothing takes the entire set of
observations into account.

.. automodapi:: probnum.filtsmooth
    :no-heading:
    :no-main-docstr:
